==> eiffelstudio-18.01.10.1424.tar: F_code/C33/gb1606.c <==
/*
 * Code for class GB_MENU_BAR_OBJECT
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "gb1606.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {GB_MENU_BAR_OBJECT}.object */
EIF_REFERENCE F2408_29209 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {GB_MENU_BAR_OBJECT}.display_object */
EIF_REFERENCE F2408_29210 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_3_);
}


/* {GB_MENU_BAR_OBJECT}.is_full */
EIF_BOOLEAN F2408_29211 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("is_full", 2407, Current, 0, 0, 35163);
	RTHOOK(1);
	RTHOOK(2);
	RTEE;
	return (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
}

/* {GB_MENU_BAR_OBJECT}.accepts_child */
EIF_BOOLEAN F2408_29212 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("accepts_child", 2407, Current, 1, 1, 35164);
	RTGC;
	RTHOOK(1);
	loc1 = F654_6403(Current, arg1);
	RTHOOK(2);
	tb1 = '\01';
	tr1 = RTOSCF(20072,F1862_20072,(Current));
	ti4_1 = F654_6403(Current, tr1);
	if (!F654_6401(Current, loc1, ti4_1)) {
		tr1 = RTOSCF(20073,F1862_20073,(Current));
		ti4_1 = F654_6403(Current, tr1);
		tb1 = F654_6401(Current, loc1, ti4_1);
	}
	if (tb1) {
		RTHOOK(3);
		RTHOOK(4);
		RTLE;
		RTEE;
		return (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	}
	RTHOOK(5);
	RTLE;
	RTEE;
	return (EIF_BOOLEAN) 0;
}

/* {GB_MENU_BAR_OBJECT}.add_child_object */
void F2408_29213 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLR(4,tr2);
	RTLIU(5);
	
	RTEAA("add_child_object", 2407, Current, 1, 2, 35165);
	RTGC;
	RTHOOK(1);
	loc1 = *(EIF_REFERENCE *)(RTCW(arg1) + O22331[Dtype(arg1)-2401]);
	loc1 = RTRV(eif_new_type(1583, 0x00), loc1);
	RTHOOK(2);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	F1414_13199(RTCW(tr1), arg2);
	RTHOOK(3);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	F1414_13208(RTCW(tr1), loc1);
	RTHOOK(4);
	loc1 = *(EIF_REFERENCE *)(RTCW(arg1) + O22332[Dtype(arg1)-2401]);
	loc1 = RTRV(eif_new_type(1583, 0x00), loc1);
	RTHOOK(5);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	F1414_13199(RTCW(tr1), arg2);
	RTHOOK(6);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	F1414_13208(RTCW(tr1), loc1);
	RTHOOK(7);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
	tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + _REFACS_2_);
	if ((EIF_BOOLEAN)(tr1 == NULL)) {
		RTHOOK(8);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
		F1414_13199(RTCW(tr1), arg2);
		RTHOOK(9);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
		tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_4_);
		F1414_13208(RTCW(tr1), tr2);
	}
	RTHOOK(10);
	F2402_29190(Current, arg1, arg2);
	RTHOOK(11);
	RTLE;
	RTEE;
}

void EIF_Minit1606 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.07.10.1981.tar: F_code/C33/gb1606.c <==
/*
 * Code for class GB_MENU_OBJECT
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "gb1606.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {GB_MENU_OBJECT}.object */
EIF_REFERENCE F2408_29232 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {GB_MENU_OBJECT}.display_object */
EIF_REFERENCE F2408_29233 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_3_);
}


/* {GB_MENU_OBJECT}.is_full */
EIF_BOOLEAN F2408_29234 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("is_full", 2407, Current, 0, 0, 35196);
	RTHOOK(1);
	RTHOOK(2);
	RTEE;
	return (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
}

/* {GB_MENU_OBJECT}.add_child_object */
void F2408_29235 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLR(4,tr2);
	RTLIU(5);
	
	RTEAA("add_child_object", 2407, Current, 1, 2, 35197);
	RTGC;
	RTHOOK(1);
	loc1 = *(EIF_REFERENCE *)(RTCW(arg1) + O22353[Dtype(arg1)-2401]);
	loc1 = RTRV(eif_new_type(1583, 0x00), loc1);
	RTHOOK(2);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	F1414_13203(RTCW(tr1), arg2);
	RTHOOK(3);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	F1414_13212(RTCW(tr1), loc1);
	RTHOOK(4);
	loc1 = *(EIF_REFERENCE *)(RTCW(arg1) + O22354[Dtype(arg1)-2401]);
	loc1 = RTRV(eif_new_type(1583, 0x00), loc1);
	RTHOOK(5);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	F1414_13203(RTCW(tr1), arg2);
	RTHOOK(6);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	F1414_13212(RTCW(tr1), loc1);
	RTHOOK(7);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
	tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + _REFACS_2_);
	if ((EIF_BOOLEAN)(tr1 == NULL)) {
		RTHOOK(8);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
		F1414_13203(RTCW(tr1), arg2);
		RTHOOK(9);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
		tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_4_);
		F1414_13212(RTCW(tr1), tr2);
	}
	RTHOOK(10);
	F2402_29213(Current, arg1, arg2);
	RTHOOK(11);
	RTLE;
	RTEE;
}

/* {GB_MENU_OBJECT}.accepts_child */
EIF_BOOLEAN F2408_29236 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("accepts_child", 2407, Current, 1, 1, 35198);
	RTGC;
	RTHOOK(1);
	loc1 = F654_6403(Current, arg1);
	RTHOOK(2);
	tb1 = '\01';
	tr1 = RTOSCF(20076,F1862_20076,(Current));
	ti4_1 = F654_6403(Current, tr1);
	if (!F654_6401(Current, loc1, ti4_1)) {
		tr1 = RTOSCF(20077,F1862_20077,(Current));
		ti4_1 = F654_6403(Current, tr1);
		tb1 = F654_6401(Current, loc1, ti4_1);
	}
	if (tb1) {
		RTHOOK(3);
		RTHOOK(4);
		RTLE;
		RTEE;
		return (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	}
	RTHOOK(5);
	RTLE;
	RTEE;
	return (EIF_BOOLEAN) 0;
}

void EIF_Minit1606 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
